import React, { PropTypes } from 'react'
import { css } from 'glamor'
import Box from './Box'
import DoubleTriangle from './DoubleTriangle'
import theme from './theme'
import splitProps from '../utils/splitProps'
const { minorScale, majorScale } = theme

const SelectWrapperBox = props => <Box {...css({
  '& select': {
    border: 'none',
    appearance: 'none',
    color: theme.backgrounds.white.textColor,
    boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
    backgroundColor: 'white'
  },
  '& > select:focus, & > select:active': {
    outline: 'none',
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary}`
  }
})} {...props} />

SelectWrapperBox.displayName = 'SelectWrapperBox'

const SelectIcon = props => <DoubleTriangle {...props} />

SelectIcon.defaultProps = {
  fill: theme.colors.darkTint,
  position: 'absolute',
  style: {
    transform: 'translateY(-50%)',
    pointerEvents: 'none'
  },
  top: '50%',
  right: minorScale(3)
}

SelectIcon.displayName = 'SelectIcon'

const renderOptions = (options = []) => {
  return options
    .map(item => typeof item === 'object' ? item : ({ value: item, label: item }))
    .map((item, i) => (
      <option key={`option__${item.value}__${i}`} value={item.value}>
        {item.label}
      </option>
    ))
}

const Select = ({ options, children, ...props }) => {
  const { matchedProps, unmatchedProps } = splitProps(props,
    /margin|width|height|display/gi)

  return (
    <SelectWrapperBox position='relative' display='flex' {...matchedProps}>
      <SelectIcon />
      <Box flex='1' {...unmatchedProps}>{options ? renderOptions(options) : children}</Box>
    </SelectWrapperBox>
  )
}

Select.propTypes = {
  options: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.shape({
      value: PropTypes.string,
      label: PropTypes.string
    })
  ])
}

Select.defaultProps = {
  is: 'select',
  rounded: true,
  paddingX: majorScale(2),
  paddingY: majorScale(1),
  textStyle: 'body1'
}

Select.displayName = 'Select'

export default Select
