import { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import theme from './../components/theme'

export const propTypes = {
  textStyle: PropTypes.oneOf(Object.keys(theme.textStyles)),
  bold: PropTypes.bool,
  textColor: PropTypes.oneOf(Object.keys(theme.textColors))
}

const getTextStyle = ({ fontSize, fontWeight, lineHeight, letterSpacing, textTransform, fontFamily, color }, textStyle) => ({
  '&, & .ui-lib-box': {
    ...(fontSize ? { fontSize } : {}),
    ...(fontWeight ? { fontWeight } : {}),
    ...(lineHeight ? { lineHeight } : {}),
    ...(letterSpacing ? { letterSpacing } : {}),
    ...(textTransform ? { textTransform } : {}),
    ...(fontFamily ? { fontFamily } : {}),
    ...(color ? { color } : {})
  }
})

const getClassName = ({
  textStyle
}) => css({
  ...(textStyle ? getTextStyle(theme.textStyles[textStyle], textStyle) : {})
})

export const parseProps = ({
  textStyle,
  textColor,
  bold,
  className,
  ...props
}) => {
  if (textStyle !== undefined || bold !== undefined || textColor !== undefined) {
    return {
      className: cx(
        `${getClassName({ textStyle, bold })}`,
        bold && `${css({ fontWeight: '500' })}`,
        textColor && `${css({ color: theme.textColors[textColor] })}`,
        className
      ),
      ...props
    }
  }
  return { className, ...props }
}
